@@ -1,7 +1,7 @@
 package Bencher::Scenario::DataCSel::Startup;
 
-our $DATE = '2016-04-01'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-04-12'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 our $scenario = {
     summary => 'Benchmark startup overhead of loading Data::CSel and parsing expressions',
@@ -27,7 +27,7 @@ Bencher::Scenario::DataCSel::Startup - Benchmark startup overhead of loading Dat
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::DataCSel::Startup (from Perl distribution Bencher-Scenarios-DataCSel), released on 2016-04-01.
+This document describes version 0.03 of Bencher::Scenario::DataCSel::Startup (from Perl distribution Bencher-Scenarios-DataCSel), released on 2016-04-12.
 
 =head1 SYNOPSIS
 
@@ -57,16 +57,16 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2557M CPU @ 1.70GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17 >>, OS kernel: I<< Linux version 3.13.0-32-generic >>.
+Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m DataCSel::Startup >>):
 
  +-----------------+-----------+-----------+------------+---------+---------+
  | participant     | rate (/s) | time (ms) | vs_slowest | errors  | samples |
  +-----------------+-----------+-----------+------------+---------+---------+
- | load_csel_parse | 56        | 18        | 1          | 2e-05   | 21      |
- | load_csel       | 57        | 17        | 1          | 7.6e-05 | 20      |
- | perl            | 141       | 7.08      | 2.5        | 3.6e-06 | 20      |
+ | load_csel_parse | 1.1e+02   | 8.8       | 1          | 3.5e-05 | 20      |
+ | load_csel       | 1.2e+02   | 8.6       | 1          | 3.8e-05 | 20      |
+ | perl            | 3.3e+02   | 3.1       | 2.9        | 7.1e-06 | 20      |
  +-----------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
